@section('title', 'VisiMisi')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Visi Misi {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Visi Misi" />

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi STKIP</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    “Menjadi universitas yang Bermutu, Bermartabat, Mandiri Dan Berorientasi Kewirausahaan (Entrepreuneurship)” 
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi STKIP</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                   <li>Menyelenggarakan program pendidikan yang bermutu sesuai dengan perkembangan jaman di era globalisasi.</li>        
                   <li>Membentuk dan membangun Sumber Daya Manusia berpengetahuan dan berketerampilan sesuai kebutuhan pasar.</li>        
                   <li>Mengembangkan dan membentuk Sumber Daya Manusia berkarakter mandiri dan berorientasi kewirausahaan.</li>        
                   <li>Melaksanakan penelitian dalam rangka pengembangan ilmu pengetahuan, teknologi dan seni yang bermuara kepada peningkatan kualitas hidup masyarakat.</li>  
                   <li>Melaksanakan pengabdian masyarakat sebagai mitra pemerintah, dalam bentuk partisipasi yang terkait dengan upaya pembangunan dan perbaikan kehidupan masyarakat.</li>  

               
                </ul>
            </div>

            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi IAI</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    “Menghasilkan lulusan yang memiliki pengetahuan luas dengan landasan imtaq, berakhlak mulia, berjiwa Pancasila, dan tanggap terhadap perkembangan ilmu dan teknologi serta mampu mengamalkan keahlian menurut profesinya bagi kepentingan masyarakat”. 
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi IAI</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                   <li>Menyelenggarakan program pendidikan Islam yang sesuai dengan kemajuan dan perkembangan ilmu pengetahuan dan teknologi untuk mengantarkan peserta didik menjadi manusia yang berpengetahuan luas yang beriman dan bertaqwa serta berakhlak mulia.</li>        
                   <li>Melaksanakan kegiatan penanaman jiwa Pancasila bagi pembinaan mahasiswa melalui upaya pembinaan secara terpadu antara kegiatan intra dan ekstra kampus.</li>        
                   <li>Meningkatkan kegiatan Tri Darma Perguruan Tinggi untuk kepentingan dan kemajuan masyarakat sesuai dengan profesinya.</li>        
                   <li>Meningkatkan kerjasama dengan berbagai lembaga dalam bidang tri darma perguruan tinggi.</li>  


               
                </ul>
            </div>
            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg" style="color:#fff">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold  mb-3">Bergabunglah dengan {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}
                    </h2>
                    <p data-aos="fade-up" class=" font-dmsans mb-5">Wujudkan impianmu dan raih masa depan cerah bersama {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}</p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-yellow-400 hover:bg-primary font-medium py-2 px-3 rounded-md text-sm transition-all text-center text-white">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
@endsection
