<!DOCTYPE html>
<html lang="en">

<head>
<!DOCTYPE html>
<html lang="id">

<head>

    <meta charset="utf-8">
    <meta name="description" content="Sekolah tinggi llmu komunikasi (STIKOM) Bandung  merupakan institusi pendidikan Sekolah Tinggi yang berfokus pada pembelajaran berbasis industri, membekali mahasiswa dengan keterampilan praktis dan materi yang siap diterapkan di dunia kerja. STIKOM BANDUNG menawarkan program S1 Ilmu Hukum, S1 Ilmu Komunikasi, S1 Manajemen, dan S1 Kewirausahaan dengan biaya terjangkau, mulai dari Rp 950.000 per bulan. Didukung oleh fasilitas modern, tenaga pengajar profesional, serta kerja sama industri yang luas, STIKOM BANDUNG berkomitmen mencetak lulusan yang kompeten, inovatif, dan siap bersaing dalam dunia industri. Bergabunglah bersama kami dan raih masa depan yang cerah.">
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, Sekolah tinggi llmu komunikasi (STIKOM) BANDUNG, kampus Sekolah tinggi llmu komunikasi (STIKOM) BANDUNG , biaya kuliah kampus STIKOM BANDUNG , biaya kuliah, kelas sabtu, akreditasi STIKOM BANDUNG, kelas karyawan terjangkau BANDUNG , S1 Ilmu Hukum, S1 Ilmu Komunikasi, S1 Manajemen, S1 Kewirausahaan, kampus murah Di BANDUNG , kampus Di BANDUNG , STIKOM BANDUNG, biaya kuliah, kelas sabtu, akreditasi Sekolah tinggi llmu komunikasi (STIKOM) BANDUNG ,
     Kampus Kelas Karyawan Di BANDUNG , Kuliah Sambil Kerja Di BANDUNG , Sekolah Tinggi Terbaik di BANDUNG  untuk Karyawan, Biaya Kuliah Terjangkau di BANDUNG , Sekolah Tinggi Kelas Sabtu Minggu Di BANDUNG , Akreditasi Sekolah Tinggi Di BANDUNG ,Perguruan Tinggi Swasta Murah di BANDUNG  ,  Kampus Swasta Terbaik BANDUNG , Sekolah Tinggi Murah  Di BANDUNG  terakreditasi Baik,
     Kampus Terjangkau di BANDUNG  untuk Karyawan, , Kuliah dengan Biaya Mulai Rp 950.000 per bulan di BANDUNG  , Sekolah Tinggi dengan Kelas Online BANDUNG , Kampus Swasta Kelas Sabtu Minggu di BANDUNG , Biaya Kuliah  Diploma Murah di BANDUNG , Biaya Kuliah  S1 Murah di BANDUNG  , Kampus dengan Program Studi Lengkap di BANDUNG " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; Sekolah tinggi llmu komunikasi (STIKOM) BANDUNG (Kelas Karyawan)</title>
    <meta property="og:title" content="Sekolah tinggi llmu komunikasi (STIKOM) BANDUNG (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="Sekolah tinggi llmu komunikasi (STIKOM) BANDUNG (Kelas Karyawan)">
    <meta property="og:image" content="https://STIKOM BANDUNG.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Sekolah tinggi llmu komunikasi (STIKOM) Bandung  adalah institusi pendidikan vokasi yang menawarkan program S1 Ilmu Hukum, S1 Ilmu Komunikasi, S1 Manajemen, dan S1 Kewirausahaan. Dengan biaya mulai Rp 950.000 per bulan, STIKOM BANDUNG berkomitmen mencetak lulusan siap kerja melalui kurikulum berbasis industri, fasilitas modern, dan kemitraan dengan berbagai perusahaan.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Sekolah tinggi llmu komunikasi (STIKOM) BANDUNG (Kelas Karyawan) (Kelas Karyawan)">
    <meta name="twitter:description" content="Sekolah tinggi llmu komunikasi (STIKOM) Bandung  menyediakan program kelas karyawan untuk jenjang S1 dengan pilihan jurusan Teknologi Mesin, Teknologi Informasi, Administrasi Perkantoran, dan Akuntansi. Dirancang khusus bagi pekerja yang ingin meningkatkan kompetensi tanpa meninggalkan pekerjaan, program ini menawarkan jadwal fleksibel dengan biaya terjangkau mulai Rp 950.000 per bulan. Didukung oleh kurikulum berbasis industri, fasilitas modern, serta kerja sama dengan berbagai perusahaan, STIKOM BANDUNG siap mencetak lulusan yang kompeten dan berdaya saing tinggi. Tingkatkan karier Anda bersama STIKOM BANDUNG!" />
    <meta name="twitter:domain" content="   ">
    <meta name="twitter:image:src" content="https://stikombandung.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Sekolah tinggi llmu komunikasi (STIKOM) BANDUNG | Kuliah Karyawan (K2)" />
    
    
    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    
    <!-- Fonts -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500;700;900&display=swap" rel="stylesheet">

    <!-- End fonts -->

    <!-- core:css -->
    <link rel="stylesheet" href="<?php echo e(asset('../assets/vendors/core/core.css')); ?>">
    <!-- endinject -->

    <!-- Plugin css for this page -->
    <link rel="stylesheet" href="<?php echo e(asset('../assets/vendors/flatpickr/flatpickr.min.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('../../../assets/vendors/datatables.net-bs5/dataTables.bootstrap5.css')); ?>">
    <link rel="stylesheet" href="<?php echo e(asset('../../../assets/vendors/dropify/dist/dropify.min.css')); ?>">
    <!-- End plugin css for this page -->

    <!-- inject:css -->
    <link rel="stylesheet" href="<?php echo e(asset('../assets/fonts/feather-font/css/iconfont.css')); ?>">
    <!-- endinject -->

    <!-- Layout styles -->
    <link rel="stylesheet" href="<?php echo e(asset('../assets/css/demo2/style.css')); ?>">

    
    <link rel="stylesheet" href="https://cdn.ckeditor.com/ckeditor5/43.1.0/ckeditor5.css" />
    <!-- End layout styles -->

    <link rel="shortcut icon" href="<?php echo e(asset('./assets/images/favicon.png')); ?>" />
    <link rel="stylesheet" type="text/css" href="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.css">

    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/apexcharts/3.44.2/apexcharts.min.css"
        integrity="sha512-qc0GepkUB5ugt8LevOF/K2h2lLGIloDBcWX8yawu/5V8FXSxZLn3NVMZskeEyOhlc6RxKiEj6QpSrlAoL1D3TA=="
        crossorigin="anonymous" referrerpolicy="no-referrer" />

    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.7/css/jquery.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/buttons/2.4.2/css/buttons.dataTables.min.css">

    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.9.4/dist/leaflet.css"
        integrity="sha256-p4NxAoJBhIIN+hmNHrzRCf9tD/miZyoHS5obTRR9BMY=" crossorigin="" />

    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css" rel="stylesheet">
    <link rel="stylesheet"
        href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datepicker/1.9.0/css/bootstrap-datepicker.min.css">

    <!-- DataTables CSS -->
    <link href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css" rel="stylesheet">

    <style>
        * {
            box-sizing: border-box !important;
        }
    </style>
</head>

<body>
    <div class="main-wrapper">

        <!-- partial:partials/_sidebar.html -->
        <?php echo $__env->make('dashboard.sidebar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
        <!-- partial -->

        <div class="page-wrapper">

            <!-- partial:partials/_navbar.html -->
            <?php echo $__env->make('dashboard.header', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
            <!-- partial -->
            <?php echo $__env->yieldContent('content'); ?>
            <!-- partial:partials/_footer.html -->
            <?php echo $__env->make('dashboard.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
            <!-- partial -->

        </div>
    </div>

    <script src="https://cdn.ckeditor.com/4.21.0/standard/ckeditor.js"></script>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/xlsx/0.18.5/xlsx.full.min.js"></script>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const exportButton = document.getElementById('exportButton');

            if (!exportButton) {
                console.error("Export button not found.");
                return;
            }

            console.log("Export button found, adding event listener.");
            exportButton.addEventListener('click', function() {
                console.log("Export button clicked.");
                exportData();
            });

            function exportData() {
                console.log("Exporting data...");
                var table = document.getElementById("dataTables-example");

                if (!table) {
                    console.error("Table not found.");
                    return;
                }

                var rows = [];
                var headers = [];

                for (var i = 0; i < table.rows[0].cells.length; i++) {
                    if (table.rows[0].cells[i].style.display !== 'none') {
                        headers.push(table.rows[0].cells[i].innerText);
                    }
                }
                rows.push(headers);

                for (var i = 1, row; row = table.rows[i]; i++) {
                    var rowData = [];
                    for (var j = 0; j < row.cells.length; j++) {
                        if (row.cells[j].style.display !== 'none') {
                            rowData.push(row.cells[j].innerText);
                        }
                    }
                    rows.push(rowData);
                }

                var ws = XLSX.utils.aoa_to_sheet(rows);
                var wb = XLSX.utils.book_new();
                XLSX.utils.book_append_sheet(wb, ws, "Data Pendaftaran");

                XLSX.writeFile(wb, "Data_Pendaftaran.xlsx");
                console.log("Export completed.");
            }
        });
    </script>

    <!-- DataTables Scripts -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>


    <!-- DataTables JavaScript -->
    <script src="vendor/datatables/js/jquery.dataTables.min.js"></script>
    <script src="vendor/datatables-plugins/dataTables.bootstrap.min.js"></script>
    <script src="vendor/datatables-responsive/dataTables.responsive.js"></script>
    <script src="/assets/js/bootstrap-datepicker.js"></script>

    <script>
        $(function() {
            $("#datepicker").datepicker({
                format: 'dd-mm-yyyy',
                autoclose: true
            }).on('changeDate', function(ev) {
                $(this).datepicker('hide');
            });
            $("#datepicker1").datepicker({
                format: 'dd-mm-yyyy',
                autoclose: true
            }).on('changeDate', function(ev) {
                $(this).datepicker('hide');
            });
        });
    </script>
    <script type="text/javascript">
        function cetak(url) {
            var tglawal = $('#datepicker').val();
            var tglakhir = $('#datepicker1').val();
            if (tglawal == '' || tglakhir == '') {
                alert('Tanggal harus diisi');
            } else {
                // alert('Bagus');
                window.location.replace(url + "?tglawal=" + tglawal + "&tglakhir=" + tglakhir);
            }
        }
    </script>

    <!-- core:js -->
    <script src="<?php echo e(asset('../../../assets/vendors/core/core.js')); ?>"></script>
    <!-- endinject -->

    <!-- Plugin js for this page -->
    <script src="<?php echo e(asset('../assets/vendors/flatpickr/flatpickr.min.js')); ?>"></script>
    <script src="<?php echo e(asset('../assets/vendors/apexcharts/apexcharts.min.js')); ?>"></script>
    <script src="<?php echo e(asset('../../../assets/vendors/datatables.net/jquery.dataTables.js')); ?>"></script>
    <script src="<?php echo e(asset('../../../assets/vendors/datatables.net-bs5/dataTables.bootstrap5.js')); ?>"></script>
    <script src="<?php echo e(asset('../../../assets/vendors/dropify/dist/dropify.min.js')); ?>"></script>
    <!-- End plugin js for this page -->

    <!-- inject:js -->
    <script src="<?php echo e(asset('../assets/vendors/feather-icons/feather.min.js')); ?>"></script>
    <script src="<?php echo e(asset('../assets/js/template.js')); ?>"></script>
    <!-- endinject -->

    <!-- Custom js for this page -->
    <script src="<?php echo e(asset('../assets/js/dashboard-light.js')); ?>"></script>
    <script src="<?php echo e(asset('../../../assets/js/data-table.js')); ?>"></script>
    <script src="<?php echo e(asset('../../../assets/js/dropify.js')); ?>"></script>
    <!-- End custom js for this page -->

    <script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.js"></script>

    <script src="https://code.jquery.com/jquery-3.7.0.js"></script>
    <script src="https://cdn.datatables.net/1.13.7/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.4.2/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.10.1/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.4.2/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.4.2/js/buttons.print.min.js"></script>

    <?php echo $__env->yieldPushContent('script'); ?>

    <script>
        toastr.options = {
            "closeButton": true, // Tombol untuk menutup pesan
            "progressBar": true, // Menambahkan progress bar
            "timeOut": "5000" // Durasi tampil pesan dalam milidetik (5 detik)
        };

        <?php if(Session::has('message')): ?>
            var type = "<?php echo e(Session::get('alert-type', 'info')); ?>";
            switch (type) {
                case 'info':
                    toastr.info("<?php echo e(Session::get('message')); ?>");
                    break;
                case 'success':
                    toastr.success("<?php echo e(Session::get('message')); ?>");
                    break;
                case 'warning':
                    toastr.warning("<?php echo e(Session::get('message')); ?>");
                    break;
                case 'error':
                    toastr.error("<?php echo e(Session::get('message')); ?>");
                    break;
            }
        <?php endif; ?>
    </script>


    <script type="importmap">
    {
        "imports": {
            "ckeditor5": "https://cdn.ckeditor.com/ckeditor5/43.1.0/ckeditor5.js",
            "ckeditor5/": "https://cdn.ckeditor.com/ckeditor5/43.1.0/"
        }
    }
    </script>

</body>

</html>
<?php /**PATH /home/u645251767/domains/stit-alfarbi.info/BUSTANUL/resources/views/dashboard/app.blade.php ENDPATH**/ ?>