<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="description" content="STITNU Al Farabi Pangandaran adalah perguruan tinggi berbasis nilai-nilai Islami yang berlokasi di Pangandaran. STITNU Al Farabi menawarkan berbagai program studi unggulan jenjang S1, seperti S1 Manajemen Pendidikan Islam, Pendidikan Islam Anak Usia Dini, S1 HKI, dan Manajemen Bisnis Islam. Dengan biaya kuliah yang terjangkau, STITNU Al Farabi menjadi pilihan tepat bagi calon mahasiswa yang mencari pendidikan berkualitas, lingkungan akademik yang mendukung, serta pengembangan karakter islami. Dapatkan pengalaman belajar yang modern, relevan dengan kebutuhan dunia kerja, dan bernilai keislaman di STITNU Al Farabi.">
    <meta name="keywords" content="edunitas, Kelas karyawan, Kuliah karyawan, STITNU Al Farabi , kampus STITNU Al Farabi , biaya kuliah kampus STITNU Al Farabi , biaya kuliah, kelas sabtu, akreditasi STITNU Al Farabi, kelas karyawan terjangkau Pangandaran , jenjang S1, seperti S1 Manajemen Pendidikan Islam, Pendidikan Islam Anak Usia Dini, S1 HKI, dan Manajemen Bisnis Islam, kampus murah Di Pangandaran, kampus Di Pangandaran , STITNU Al Farabi, biaya kuliah, kelas sabtu, akreditasi STITNU Al Farabi ,
     Kampus Kelas Karyawan Di Lombok , Kuliah Sambil Kerja Di Lombok , Universitas Terbaik di Lombok  untuk Karyawan, Biaya Kuliah Terjangkau di Lombok , Universitas Kelas Sabtu Minggu Di Lombok , Akreditasi Universitas Di Pangandaran ,Perguruan Tinggi Swasta Murah di Pangandaran,  Kampus Swasta Terbaik Pangandaran , Universitas Murah  Di Pangandaran  terakreditasi Baik,
     Kampus Terjangkau di Pangandaran  untuk Karyawan , Kuliah dengan Biaya Murah di Pangandaran  , Universitas dengan Kelas Online Pangandaran , Kampus Swasta Kelas Sabtu Minggu di Pangandaran , Biaya Kuliah  Sarjana Murah di Pangandaran , Biaya Kuliah S1 Murah di Pangandaran  , Kampus dengan Program Studi Lengkap di Pangandaran " />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <!--ADS GSC-->

    
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; Institut STITNU Al Farabi (Kelas Karyawan)</title>
    <meta property="og:title" content="Institut STITNU Al Farabi (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="Institut STITNU Al Farabi (Kelas Karyawan)">
    <meta property="og:image" content="https://stit-alfarabi.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Institut STITNU Al Farabi di Kota Pangandaran menawarkan program S1 Manajemen, Akuntansi, Pendidikan Bahasa Inggris, dan Pendidikan Matematika.Serta jenjang D3, seperti D3 Ilmu Komputer, dan Manajemen Informatika dengan biaya kuliah terjangkau. Pilihan tepat untuk pendidikan berkualitas berbasis nilai-nilai Islami.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Institut STITNU Al Farabi (Kelas Karyawan)">
    <meta name="twitter:description" content="Institut STITNU Al Farabi di Kota Pangandaran menyediakan program Kelas Karyawan dengan biaya kuliah terjangkau untuk jenjang S1 Manajemen, Akuntansi, Pendidikan Bahasa Inggris, dan Pendidikan Matematika.Serta jenjang D3, seperti D3 Ilmu Komputer, dan Manajemen Informatika. Dirancang khusus bagi pekerja dan profesional yang ingin melanjutkan pendidikan tanpa mengganggu aktivitas kerja, STITNU Al Farabi menawarkan jadwal fleksibel, suasana akademik islami, serta kurikulum yang relevan dengan kebutuhan dunia kerja. Raih gelar sarjana sambil tetap produktif bersama STITNU Al Farabi Kelas Karyawan!" />
    <meta name="twitter:domain" content="   ">
    <meta name="twitter:image:src" content=https://stit-alfarabi.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
    
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    <?php echo $__env->yieldContent('content'); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH /home/u645251767/domains/stit-alfarabi.info/ALFARABI/resources/views/auth/app.blade.php ENDPATH**/ ?>