<?php $__env->startSection('title', 'VisiMisi'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Visi Misi '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Visi Misi']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                Pada tahun 2049, UHAFIZ menjadi Pusat Pendidikan dan Pengembangan IPTEKS kelas dunia yang berbasis pada penguatan kearifan lokal Sunda dan keunggulan produk lokal
                Cianjur, guna menciptakan SDM yang cendekia, mandiri, inovatif, dan adaptif.
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                <li>
                    Menyelenggarakan dan mengembangkan pendidikan yang memiliki daya saing kelas dunia yang cendikia, mandiri dan berakhlakul 
                    karimah dalam pengembangan ilmu pengetahuan dan teknologi.
                </li>
                <li>
                    Menyelenggarakan dan mengembangkan penelitian yang memiliki daya saing global untuk pengembangan ilmu pengetahuan dan teknologi, 
                    serta memperoleh kontribusi yang inovatif dan relevan dengan berbasis kearifan lokal.
                </li>
                 <li>
                    Menyelenggarakan dan mengembangkan pengabdian kepada masyarakat yang memiliki daya saing global melalui kegiatan kreatif dan 
                    inovatif dalam pengembangan ilmu pengetahuan dan teknologi serta pengembangan sumberdaya yang cendikia, mandiri dan beraklakul kharimah.

                </li>
                <li>
                    Menyelenggarakan tata kelola yang baik melalui pengembangan kelembagaan yang berorientasi pada mutu dan mampu 
                    beradaptasi dengan perubahan kondisi strategis.
                </li>
                
               
                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg" style="color:#fff">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold  mb-3">Bergabunglah dengan <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>

                    </h2>
                    <p data-aos="fade-up" class=" font-dmsans mb-5">Wujudkan impianmu dan raih masa depan cerah bersama <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?></p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="bg-white text-primary font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/u645251767/domains/uhafiz.info/UHAFIZ/resources/views/Frontend/visimisi.blade.php ENDPATH**/ ?>