<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="utf-8">
    <meta name="description" content="STKIP & IAI Al-Amin Indramayu atau yang biasa dikenal IAI Al - Amin Indramayu salah satu Perguruan Tinggi Swasta Terbaik di Indramayu, tersedia kelas karyawan dengan biaya murah dan terjangkau mulai dari Rp 595.000/Bulan dengan jurusan S1 Pendidikan Agama Islam, S1 Pendidikan Guru Madrasah Ibtidaiyah, S1 Pendidikan Guru Paud, S1 Hukum Keluarga Islam, S1 Manajemen Pendidikan Islam, S1 Eknomi Syariah dan Rp 900.000/Bulan dengan jurusan S1 Pendidikan Agama Islam, S1 Pendidikan Guru Madrasah Ibtidaiyah, S1 Pendidikan Guru Paud, S1 Hukum Keluarga Islam, S1 Manajemen Pendidikan Islam, S1 Eknomi Syariah" />
    <meta name="keywords" content="Kelas karyawan, Kuliah karyawan, STKIP & IAI Al-Amin Indramayu , kampus STKIP & IAI Al-Amin Indramayu, biaya kuliah kampus STKIP & IAI Al-Amin Indramayu, STKIP & IAI Al-Amin Indramayu, biaya kuliah, kelas sabtu, akreditasi STKIP & IAI Al-Amin Indramayu, kelas karyawan terjangkau Indramayu, S1 Pendidikan Agama Islam, S1 Pendidikan Guru Madrasah Ibtidaiyah, S1 Pendidikan Guru Paud, S1 Hukum Keluarga Islam, S1 Manajemen Pendidikan Islam, S1 Eknomi Syariah kampus murah, kampus Indramayu, kampus Indramayu." />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
            
    <title><?php echo $__env->yieldContent('title'); ?> &mdash; STKIP & IAI Al-Amin Indramayu (Kelas Karyawan)</title>
    <meta property="og:title" content="STKIP & IAI Al-Amin Indramayu (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://alamin-indramayu.info">
    <meta property="og:image" content="https://alamin-indramayu.info/images/background/hero1.png">
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STKIP & IAI Al-Amin Indramayu atau yang biasa dikenal IAI Al - Amin Indramayu salah satu Perguruan Tinggi Swasta Terbaik di Indramayu, tersedia kelas karyawan dengan biaya murah dan terjangkau mulai dari Rp 595.000/Bulan dengan jurusan S1 Pendidikan Agama Islam, S1 Pendidikan Guru Madrasah Ibtidaiyah, S1 Pendidikan Guru Paud, S1 Hukum Keluarga Islam, S1 Manajemen Pendidikan Islam, S1 Eknomi Syariah dan Rp 900.000/Bulan dengan jurusan S1 Pendidikan Agama Islam, S1 Pendidikan Guru Madrasah Ibtidaiyah, S1 Pendidikan Guru Paud, S1 Hukum Keluarga Islam, S1 Manajemen Pendidikan Islam, S1 Eknomi Syariah">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STKIP & IAI Al-Amin Indramayu (Kelas Karyawan)">
    <meta name="twitter:description" content="STKIP & IAI Al-Amin Indramayu atau yang biasa dikenal IAI Al - Amin Indramayu salah satu Perguruan Tinggi Swasta Terbaik di Indramayu, tersedia kelas karyawan dengan biaya murah dan terjangkau mulai dari Rp 595.000/Bulan dengan jurusan S1 Pendidikan Agama Islam, S1 Pendidikan Guru Madrasah Ibtidaiyah, S1 Pendidikan Guru Paud, S1 Hukum Keluarga Islam, S1 Manajemen Pendidikan Islam, S1 Eknomi Syariah dan Rp 900.000/Bulan dengan jurusan S1 Pendidikan Agama Islam, S1 Pendidikan Guru Madrasah Ibtidaiyah, S1 Pendidikan Guru Paud, S1 Hukum Keluarga Islam, S1 Manajemen Pendidikan Islam, S1 Eknomi Syariah">
    <meta name="twitter:domain" content="https://alamin-indramayu.info">
    <meta name="twitter:image:src" content="https://alamin-indramayu.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STKIP & IAI Al-Amin Indramayu  | Kuliah Karyawan (K2)" />
    
     <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    
    <link href="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.css" rel="stylesheet" />

    <!-- Add Poppins font -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link
        href="https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap"
        rel="stylesheet">

    <script src="https://cdn.tailwindcss.com?plugins=forms,typography,aspect-ratio,line-clamp,container-queries"></script>
</head>

<body class="font-poppins h-screen flex items-center justify-center bg-cover bg-center">
    <?php echo $__env->yieldContent('content'); ?>

    
    <script src="https://cdn.jsdelivr.net/npm/flowbite@2.5.2/dist/flowbite.min.js"></script>
    <!-- Font Awesome for icons (used for Twitter icon) -->
    <script src="https://kit.fontawesome.com/a076d05399.js" crossorigin="anonymous"></script>

    
    <?php echo $__env->yieldPushContent('scripts'); ?>
</body>

</html>
<?php /**PATH /home/u142502046/domains/alamin-indramayu.info/IAI/resources/views/auth/app.blade.php ENDPATH**/ ?>