@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
<br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}" breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p class="text-justify" style="font-size: 14px;">

STKIP Al-Amin Indramayu merupakan Perguruan Tinggi Swasta di bawah naungan Yayasan Al-Amin Indramayu yang bergerak dalam peningkatan Sumber Daya Manusia (SDM) khususnya dalam bidang pendidikan Islam. STKIP Al-Amin Indramayu mempunyai 4 prodi yaitu: Pendidikan Ilmu Pengetahuan Alam, Pendidikan Guru Seklah Dasar, Pendidikan Bahasa Inggris dan Pendidikan Ilmu Pengetahuan Sosial. <br><br>

Proses berdirinya STIT AL-AMIN Indramayu ini bermula dari atas keprihatinan 4 tokoh setempat atas Sumber Daya Manusia (SDM) di daerah Indramayu Barat. Mengingat di Indramayu Barat belum ada Perguruan Tinggi Islam. 4 Tokoh tersebut adalah K.H. Moh. Syatori, MA, Dr. H. Ahmad, M. Ag. Abah Tarwijan, dan Dr. H. Lukman, M.Ag. Muncullah kesepakatan perlunya didirikan sebuah perguruan tinggi Islam. Bermula menginduk di STIT Riyadul Jannah Subang Tahun 2003. Dengan jumlah mahasiswa 10 orang. Dan bertempat di gedung MI PUI Kemped Wirakanan Kandanghaur Indramayu. Setelah diadakan studi kelayakan dan konsultasi dengan berbagai pihak, antara lain dengan pimpinan Kopertais Wilayah 4 Jawa Barat dan Bupati Indramayu, maka terwujudlah niat mendirikan perguruan tinggi sebagaimana dimaksud di atas, dengan nama “Sekolah Tinggi Ilmu Tarbiyah (STIT) Al Amin Indramayu.<br><br>

Secara resmi STIT Al-Amin Indramayu ini dinyatakan berdiri pada tanggal 13 Oktober 2005 dengan jumlah mahasiswa pertama sebanyak 20 Orang. Kemudian di tahun 2005 STIT Al-Amin Indramayu di bawah naungan Yayasan Al-Amin.. Adapun latar belakang berdirinya STIT Al-Amin Indramayu ini antara lain: Di lingkungan Desa Kemped Wirakanan telah ada beberapa jenjang pendidikan Namun belum pendidikan Perguruan Tnggi sehingga yang semangat keagamaan masyarakatnya sangat tinggi dan jumlah lembaga pendidikan tingkat SLTA sangat banyak dirasa masih terlalu sedikit. Akibatnya cukup banyak generasi Islam yang ingin meneruskan pendidikannya ke jenjang yang lebih tinggi tidak mampu tertampung di perguruan tinggi yang sudah ada; Ingin mewujudkan amar ma’ruf nahi munkar serta syiar Islam melalui perguruan Tinggi. Sedangkan tujuan berdirinya, antara lain ialah: Mencetak sarjana-sarjana muslim yang berakhlak mulia, berilmu dan cakap serta memiliki kesadaran bertanggung jawab antara kesejahteraan umat dan masa depan bangsa dan negara Republik Indonesia dan berdasarkan Pancasila. Mencetak sarjana-sarjana muslim yang mandiri dan melayani masyarakat. Mencetak sarjanasarjana muslim yang berakhlak mulia, berilmu dan cakap serta memiliki kesadaran bertanggung jawab antara kesejahteraan umat dan masa depan bangsa dan negara Republik Indonesia dan berdasarkan Pancasila. Mencetak sarjana-sarjana muslim yang mandiri dan melayani masyarakat. <br>



                
            </p>

        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
